ComprehensiveAuthProvider

Struct ComprehensiveAuthProvider 

pub struct ComprehensiveAuthProvider { /* private fields */ }
Comprehensive authentication provider with password auth and ACL support

Implementations

Source

impl ComprehensiveAuthProvider

pub fn new() -> Self

pub fn with_providers( password_provider: PasswordAuthProvider, acl_manager: AclManager, ) -> Self

pub async fn from_files( password_file: impl AsRef<Path>, acl_file: impl AsRef<Path>, ) -> Result<Self>

Creates a comprehensive auth provider with password file and ACL file

Errors

Returns an error if files cannot be loaded

pub async fn with_password_file_and_allow_all_acl( password_file: impl AsRef<Path>, ) -> Result<Self>

Creates a comprehensive auth provider with allow-all ACL

Errors

Returns an error if the password file cannot be loaded

pub fn password_provider(&self) -> &PasswordAuthProvider

pub fn acl_manager(&self) -> &AclManager

pub async fn reload(&self) -> Result<()>

Reloads password and ACL files

Errors

Returns an error if files cannot be reloaded